==> WPyrogram-2.0.109-py3-none-any.whl: pyrogram/raw/functions/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .req_pq import ReqPq
from .req_pq_multi import ReqPqMulti
from .req_dh_params import ReqDHParams
from .set_client_dh_params import SetClientDHParams
from .destroy_auth_key import DestroyAuthKey
from .rpc_drop_answer import RpcDropAnswer
from .get_future_salts import GetFutureSalts
from .ping import Ping
from .ping_delay_disconnect import PingDelayDisconnect
from .destroy_session import DestroySession
from .invoke_after_msg import InvokeAfterMsg
from .invoke_after_msgs import InvokeAfterMsgs
from .init_connection import InitConnection
from .invoke_with_layer import InvokeWithLayer
from .invoke_without_updates import InvokeWithoutUpdates
from .invoke_with_messages_range import InvokeWithMessagesRange
from .invoke_with_takeout import InvokeWithTakeout
from . import contest, auth, account, users, contacts, messages, updates, photos, upload, help, channels, bots, payments, stickers, phone, langpack, folders, stats, chatlists, stories

==> WPyrogram-2.0.132-py3-none-any.whl: pyrogram/raw/functions/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .req_pq import ReqPq
from .req_pq_multi import ReqPqMulti
from .req_dh_params import ReqDHParams
from .set_client_dh_params import SetClientDHParams
from .destroy_auth_key import DestroyAuthKey
from .rpc_drop_answer import RpcDropAnswer
from .get_future_salts import GetFutureSalts
from .ping import Ping
from .ping_delay_disconnect import PingDelayDisconnect
from .destroy_session import DestroySession
from .invoke_after_msg import InvokeAfterMsg
from .invoke_after_msgs import InvokeAfterMsgs
from .init_connection import InitConnection
from .invoke_with_layer import InvokeWithLayer
from .invoke_without_updates import InvokeWithoutUpdates
from .invoke_with_messages_range import InvokeWithMessagesRange
from .invoke_with_takeout import InvokeWithTakeout
from . import contest, auth, account, users, contacts, messages, updates, photos, upload, help, channels, bots, payments, stickers, phone, langpack, folders, stats, chatlists, stories, premium
